@@ -9,6 +9,15 @@ from googleapiclient.errors import HttpError
 from arcane.core.exceptions import BadRequestError
 
 
+class GoogleAnalyticsAccountLostAccessException(Exception):
+    """ Raised when we cannot access to an account """
+    pass
+
+class GoogleAnalyticsServiceDownException(Exception):
+    """ Raised when we cannot access to an account """
+    pass
+
+
 def get_metrics_from_view(ga_view: str,
                           adscale_key: str,
                           date_ranges: Dict=None,
@@ -57,12 +66,14 @@ def check_access_account(view_id: str, adscale_key):
     try:
         views = service.management().profiles().list(accountId='~all', webPropertyId='~all').execute()
     except HttpError as err:
-        print(err)
-        raise ValueError(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+        if err.resp.status >= 400 and err.resp.status < 500:
+            raise GoogleAnalyticsAccountLostAccessException(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+        else:
+            raise GoogleAnalyticsServiceDownException(f"The Google Analytics API does not respond. Thus, we cannot check if we can access your Google Analytics account with the id: {view_id}. Please try later" )
 
     if view_id not in [view.get('id') for view in views.get('items', [])]:
-        raise ValueError(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+        raise GoogleAnalyticsAccountLostAccessException(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
 
     for view in views.get('items', []):
         if view.get('id') == view_id:
-            return view.get('name')
+            return view.get('name', '')
